About this chapter

# XMLRésuméLibrary: User Guide

Where to Go from Here | Exploring the Features of XML Résumé Library | Part II. Reference

## About this chapter

This chapter was originally written by Peter Hutnick. It was edited and converted to DocBook format by Bruce Christensen. Further editing and additions were done by Mark Miller

Please send comments, suggestions, and especially corrections for this chapter to `<peter at hutnick dot com>`.

Where to Go from Here | Exploring the Features of XML Résumé Library | Part II. Reference